@@ -389,9 +389,9 @@ get.loadings <- function(CSresult){
 
 #' Compare Automatic Factor Labels with Manual Provided Labels.
 #' 
-#' With this function you can compare the automatic created labels based of the absolute loadings in \emph{CSanalysis} (\code{which=8}) with your own provided labels to investigate if there is relation between them.\cr
+#' With this function you can compare the automatic created labels based of the absolute loadings in \code{\link{CSanalysis}} (\code{which=8}) with your own provided labels to investigate if there is relation between them.\cr
 #' See the \code{type} parameter which two plots can be created.\cr
-#' Note that the automatic created factor labels in \emph{CSanalysis} denote which factors this loading has a high/low value and these can be regenerated (with different a different cut-off) by simply running \emph{CSanalysis} again. Providing \code{resultavailable} will skip the analysis computation step and only regenerate the labels.
+#' Note that the automatic created factor labels in \code{\link{CSanalysis}} denote which factors this loading has a high/low value and these can be regenerated (with different a different cut-off) by simply running \code{\link{CSanalysis}} again. Providing \code{result.available} will skip the analysis computation step and only regenerate the labels.
 #'  
 #' @export
 #' @param CSresult Object of CSresult S4 Class.
@@ -407,7 +407,7 @@ get.loadings <- function(CSresult){
 #' These factor labels are not exactly the generated labels, but simply "Factor 1", "Factor 2",..., "None" or "BC 1", "BC 2",..., "None". This means that should a loading be high/low in multiple factors, it will appear multiple times on this plot, namely for each corresponding factor.
 #' The loadings are plotted for these factor labels (with jitter) and are colored according to the manual provided labels (\code{labels}) which is shown in the legend. The coloring also shows which loadings were in the query set.
 #' }
-#' Note that if none of the loadings is high/low in multiple factors, the types of plots should be identical.
+#' \strong{Note} that if none of the loadings is high/low in multiple factors, the two types of plots should be identical.
 #' @param basefilename Base of the filename when saving the graph as a pdf (\code{plot.type="pdf"})
 #' @param plot.type How should the plots be outputted? \code{"pdf"} to save them in pdf files, \code{device} to draw them in a graphics device (default), \code{sweave} to use them in a sweave or knitr file.
 #' @examples
@@ -500,7 +500,7 @@ CSlabelscompare <- function(CSresult,labels,type="factors",basefilename="CSanaly
 			}
 			axis(1,at=1:length(factor.list),labels=names(factor.list))
 			axis(2,at=seq(-1,1,0.2))
-			legend("topright",c("Ref.",unique.truenames),col=c("blue",colors.truenames),pt.bg=c("white",colors.truenames),inset=c(-inset.temp,0),bty="n",pch=21)
+			legend("topright",c("Query",unique.truenames),col=c("blue",colors.truenames),pt.bg=c("white",colors.truenames),inset=c(-inset.temp,0),bty="n",pch=21)
 		
 		}
 		plot.out(plot.type)
@@ -535,7 +535,7 @@ CSlabelscompare <- function(CSresult,labels,type="factors",basefilename="CSanaly
 			}
 			axis(1,at=1:length(unique.factornames),labels=unique.factornames)
 			axis(2,at=seq(-1,1,0.2))
-			legend("topright",c("Ref.",unique.truenames),col=c("blue",colors.truenames),pt.bg=c("white",colors.truenames),inset=c(-inset.temp,0),bty="n",pch=21)
+			legend("topright",c("Query",unique.truenames),col=c("blue",colors.truenames),pt.bg=c("white",colors.truenames),inset=c(-inset.temp,0),bty="n",pch=21)
 			
 		}
 		plot.out(plot.type)
